==> glpi_0.78.3.orig.tar.gz: glpi/inc/ruledictionnarymanufacturercollection.class.php <==
<?php
/*
 * @version $Id: ruledictionnarymanufacturercollection.class.php 12843 2010-10-21 13:45:12Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Walid Nouh
// Purpose of file:
// ----------------------------------------------------------------------

class RuleDictionnaryManufacturerCollection extends RuleDictionnaryDropdownCollection {

   // From RuleCollection
   //public $rule_class_name = 'RuleDictionnaryManufacturer';

   // Specific ones
   /// dropdown table
   var $item_table="";

   /**
    * Constructor
   **/
   function __construct() {
      $this->item_table="glpi_manufacturers";
      //Init cache system values
      $this->initCache("glpi_rulecachemanufacturers");
      $this->menu_option="manufacturers";
   }

   function getTitle() {
      global $LANG;
            return $LANG['rulesengine'][36];
   }

}
?>

==> glpi_0.80.5.orig.tar.gz: glpi/inc/ruledictionnarymanufacturercollection.class.php <==
<?php
/*
 * @version $Id: ruledictionnarymanufacturercollection.class.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Walid Nouh
// Purpose of file:
// ----------------------------------------------------------------------

class RuleDictionnaryManufacturerCollection extends RuleDictionnaryDropdownCollection {

   // From RuleCollection
   //public $rule_class_name = 'RuleDictionnaryManufacturer';

   // Specific ones
   /// dropdown table
   var $item_table = "";


   /**
    * Constructor
   **/
   function __construct() {

      $this->item_table="glpi_manufacturers";
      //Init cache system values
      $this->initCache("glpi_rulecachemanufacturers");
      $this->menu_option="manufacturers";
   }


   function getTitle() {
      global $LANG;

      return $LANG['rulesengine'][36];
   }

}
?>
